@@ -1,6 +1,6 @@
 package Net::DNS::Packet;
 #
-# $Id: Packet.pm,v 1.22 2003/09/03 04:41:50 ctriv Exp $
+# $Id: Packet.pm,v 1.25 2003/12/11 10:04:40 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA @EXPORT_OK $VERSION $AUTOLOAD);
@@ -14,7 +14,7 @@ use Net::DNS;
 use Net::DNS::Question;
 use Net::DNS::RR;
 
-$VERSION = (qw$Revision: 1.22 $)[1];
+$VERSION = (qw$Revision: 1.25 $)[1];
 
 =head1 NAME
 
@@ -468,7 +468,7 @@ sub answerfrom {
 
 Returns the size of the packet in bytes as it was received from a
 nameserver.  User-created packets will return undef for this method
-(use C<<length $packet->data>> instead).
+(use C<< length $packet->data >> instead).
 
 =cut
 
@@ -559,11 +559,17 @@ Adds unseen RRs to the specified section of the packet. This is useful
 to insure that the packets do not contain redundant RRs in any of the
 sections.
 
+This method will no longer be available in Net::DNS::Packet soon.  It 
+should only be used on Net::DNS::Update objects. 
+
 =cut
 
 sub safe_push {
 	my ($self, $section, @rrs) = @_;
 	
+	carp "Deprecated use of safe_push() on Net::DNS::Packet object, use Net::DNS::Update."
+		unless $self->isa('Net::DNS::Update');
+	
 	foreach my $rr (@rrs) {
 		next if $self->{'seen'}->{$rr->string};
 		
@@ -888,8 +894,8 @@ sub parse_question {
 	my ($qtype, $qclass) = unpack("\@$offset n2", $$data);
 	$offset += 2 * &Net::DNS::INT16SZ;
 
-	$qtype  = $Net::DNS::typesbyval{$qtype};
-	$qclass = $Net::DNS::classesbyval{$qclass};
+	$qtype  = Net::DNS::typesbyval($qtype);
+	$qclass = Net::DNS::classesbyval($qclass);
 
 	return (Net::DNS::Question->new($qname, $qtype, $qclass), $offset);
 }
@@ -920,12 +926,12 @@ sub parse_rr {
 
 	my ($type, $class, $ttl, $rdlength) = unpack("\@$offset n2 N n", $$data);
 
-	$type  = $Net::DNS::typesbyval{$type}    || $type;
+	$type  = Net::DNS::typesbyval($type)    || $type;
 
 	# Special case for OPT RR where CLASS should be interperted as 16 bit 
 	# unsigned 2671 sec 4.3
 	if ($type ne "OPT") {
-	    $class = $Net::DNS::classesbyval{$class} || $class;
+	    $class = Net::DNS::classesbyval($class) || $class;
 	} 
 	# else just keep at its numerical value
 
