@@ -1,13 +1,14 @@
 package Net::DNS::Question;
-
+#
+# $Id: Question.pm,v 1.8 2003/12/09 17:37:13 ctriv Exp $
+#
 use strict;
 use vars qw($VERSION $AUTOLOAD);
 
 use Carp;
 use Net::DNS;
 
-# $Id: Question.pm,v 1.4 2002/05/28 08:08:25 ctriv Exp $
-$VERSION = $Net::DNS::VERSION;
+$VERSION = (qw$Revision: 1.8 $)[1];
 
 =head1 NAME
 
@@ -49,6 +50,7 @@ sub new {
 	$qclass = defined($qclass) ? uc($qclass) : "ANY";
 
 	# Check if the caller has the type and class reversed.
+	# We are not that kind for unknown types.... :-)
 	if ((!exists $Net::DNS::typesbyname{$qtype} ||
 	     !exists $Net::DNS::classesbyname{$qclass})
 	    && exists $Net::DNS::classesbyname{$qtype}
@@ -100,17 +102,32 @@ known as C<zclass> and refers to the zone's class.
 =cut
 
 sub AUTOLOAD {
-	my $self = shift;
+	my ($self) = @_;
+	
 	my $name = $AUTOLOAD;
 	$name =~ s/.*://;
 
 	Carp::croak "$name: no such method" unless exists $self->{$name};
-	return $self->{$name};
+
+	no strict q/refs/;
+	
+	*{$AUTOLOAD} = sub {
+		my ($self, $new_val) = @_;
+		
+		if (defined $new_val) {
+			$self->{"$name"} = $new_val;
+		}
+		
+		return $self->{"$name"};
+	};
+	
+	goto &{$AUTOLOAD};	
 }
 
-sub zname  { my $self = shift; $self->qname(@_);  }
-sub ztype  { my $self = shift; $self->qtype(@_);  }
-sub zclass { my $self = shift; $self->qclass(@_); }
+
+sub zname  { &qname;  }
+sub ztype  { &qtype;  }
+sub zclass { &qclass; }
 
 =head2 print
 
@@ -120,10 +137,7 @@ Prints the question record on the standard output.
 
 =cut
 
-sub print {
-	my $self = shift;
-	print $self->string, "\n";
-}
+sub print {	print $_[0]->string, "\n"; }
 
 =head2 string
 
@@ -157,17 +171,20 @@ sub data {
 
 	my $data = $packet->dn_comp($self->{"qname"}, $offset);
 
-	$data .= pack("n", $Net::DNS::typesbyname{uc($self->{"qtype"})});
-	$data .= pack("n", $Net::DNS::classesbyname{uc($self->{"qclass"})});
+	$data .= pack("n", Net::DNS::typesbyname(uc($self->{"qtype"})));
+	$data .= pack("n", Net::DNS::classesbyname(uc($self->{"qclass"})));
 	
 	return $data;
 }
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2002 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
