@@ -1,21 +1,20 @@
 package Net::DNS::RR::LOC;
-
-# $Id: LOC.pm,v 1.3 2002/02/13 03:53:59 ctriv Exp $
-
+#
+# $Id: LOC.pm,v 1.5 2003/09/03 04:41:50 ctriv Exp $
+#
 use strict;
-use vars qw(@ISA @EXPORT @EXPORT_OK @poweroften $reference_alt
-	    $reference_latlon $conv_sec $conv_min $conv_deg
-	    $default_min $default_sec $default_size
-	    $default_horiz_pre $default_vert_pre);
+use vars qw(
+        @ISA $VERSION @poweroften $reference_alt
+        $reference_latlon $conv_sec $conv_min $conv_deg
+        $default_min $default_sec $default_size
+        $default_horiz_pre $default_vert_pre
+);
 
-require Exporter;
 use Net::DNS;
 use Net::DNS::Packet;
 
-@ISA = qw(Net::DNS::RR Exporter);
-
-@EXPORT = qw();
-@EXPORT_OK = qw();
+@ISA     = qw(Net::DNS::RR);
+$VERSION = (qw$Revision: 1.5 $)[1];
 
 # Powers of 10 from 0 to 9 (used to speed up calculations).
 @poweroften = (1, 10, 100, 1_000, 10_000, 100_000, 1_000_000,
@@ -349,10 +348,12 @@ below the WGS 84 reference spheroid used by GPS.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-1998 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
 
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 Some of the code and documentation is based on RFC 1876 and on code
 contributed by Christopher Davis.
 
