@@ -1,16 +1,17 @@
 package Net::DNS::RR::OPT;
-
-# $Id: OPT.pm,v 1.3 2002/07/28 23:18:06 ctriv Exp $
-
+#
+# $Id: OPT.pm,v 1.5 2003/08/26 23:58:10 ctriv Exp $
+#
 
 use strict;
-use vars qw(@ISA %extendedrcodesbyname %extendedrcodesbyval $EDNSVERSION);
+use vars qw(@ISA $VERSION %extendedrcodesbyname %extendedrcodesbyval $EDNSVERSION);
 
 use Socket;
 use Net::DNS;
 use Carp;
 
-@ISA = qw(Net::DNS::RR);
+@ISA     = qw(Net::DNS::RR);
+$VERSION = (qw$Revision: 1.5 $)[1];
 
 $EDNSVERSION= 0 ;
 
@@ -80,10 +81,12 @@ sub new_from_hash {
     }
     
     $self->{"extendedrcode"}   = 0 unless exists $self->{"extendedrcode"};
+
     $self->{"ednsflags"}  = 0 unless exists $self->{"ednsflags"};
+    $self->{"ednsversion"}  =  $Net::DNS::RR::OPT::EDNSVERSION unless exists $self->{"ednsversion"};
     $self->{"ttl"}= unpack ("N", 
 			  pack("C", $self->{"extendedrcode"} ) .
-			  pack("C", $Net::DNS::RR::OPT::EDNSVERSION )  .
+			  pack("C", $self->{"ednsversion"} )  .
 			  pack("n", $self->{"ednsflags"}));
 
     if (exists  $self->{"optioncode"}) {
@@ -99,7 +102,8 @@ sub new_from_hash {
 
 sub string {
    my  $self=shift;
-    return "; EDNS Version ". $self->{"ednsversion"} . 
+   return
+     "; EDNS Version ". $self->{"ednsversion"} . 
         "\t UDP Packetsize: " .  $self->{"class"} . 
 	"\n; EDNS-RCODE:\t". $self->{"extendedrcode"} .
 	   " (" . $extendedrcodesbyval{ $self->{"extendedrcode"} }. ")" .
