@@ -1,14 +1,15 @@
 package Net::DNS::RR::RT;
-
-# $Id: RT.pm,v 1.3 2002/05/22 18:09:36 ctriv Exp $
-
+#
+# $Id: RT.pm,v 1.5 2003/09/03 04:41:51 ctriv Exp $
+#
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
 use Net::DNS;
 use Net::DNS::Packet;
 
-@ISA = qw(Net::DNS::RR);
+@ISA     = qw(Net::DNS::RR);
+$VERSION = (qw$Revision: 1.5 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -99,9 +100,12 @@ Returns the domain name of the intermediate host.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-1998 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
