@@ -1,14 +1,15 @@
 package Net::DNS::RR::SRV;
-
-# $Id: SRV.pm,v 1.2 2002/02/13 03:53:59 ctriv Exp $
-
+#
+# $Id: SRV.pm,v 1.6 2003/09/03 04:41:51 ctriv Exp $
+#
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
 use Net::DNS;
 use Net::DNS::Packet;
 
-@ISA = qw(Net::DNS::RR);
+@ISA     = qw(Net::DNS::RR);
+$VERSION = (qw$Revision: 1.6 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -70,6 +71,20 @@ sub rr_rdata {
 	return $rdata;
 }
 
+
+sub _canonicalRdata {
+    my $self  = shift;
+    my $rdata = '';
+    
+    if (exists $self->{"priority"}) {
+	$rdata .= pack("n3", $self->{"priority"}, $self->{"weight"},
+		       $self->{"port"});
+	$rdata .= $self->name_2wire($self->{"target"});
+	}
+
+	return $rdata;
+}
+
 1;
 __END__
 
@@ -113,9 +128,12 @@ Returns the target host.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2000 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
