@@ -1,24 +1,23 @@
 package Net::DNS::RR::Unknown;
 #
-# $Id: Unknown.pm 979 2012-01-27 08:43:38Z willem $
+# $Id: Unknown.pm,v 1.1 2003/12/11 23:26:36 ctriv Exp $
 #
 use strict;
-BEGIN {
-    eval { require bytes; }
-}
 use vars qw(@ISA $VERSION);
 
+use Net::DNS;
+
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 979 $)[1];
+$VERSION = (qw$Revision: 1.1 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
-
+	
 	my $length = $self->{'rdlength'};
-
+	
 	if ($length > 0) {
-		$self->{'rdata'}    = substr($$data, $offset,$length);
-		$self->{'rdatastr'} = "\\# $length " . unpack('H*',  $self->{'rdata'});
+	    my $hex = unpack('H*', substr($$data, $offset,$length));
+	    $self->{'rdata'} = "\\# $length $hex";
 	}
 
 	return bless $self, $class;
@@ -27,25 +26,15 @@ sub new {
 
 sub rdatastr {
 	my $self = shift;
+	return defined $self->{'rdata'} ? $self->{'rdata'} : '# NODATA';
 
-	if (exists $self->{'rdatastr'}) {
-		return $self->{'rdatastr'};
-	} else {
-		if (exists $self->{"rdata"}){
-			my $data= $self->{'rdata'};
-
-			return  "\\# ". length($data) . "  " . unpack('H*',  $data);
-		}
-	}
-
-	return "#NO DATA";
 }
 
-
-# sub rr_rdata is inherited from RR.pm. Note that $self->{'rdata'}
-# should always be defined
-
-
+sub rr_rdata {
+	my $self  = shift;
+	my $rdata = '';
+	return $rdata;
+}
 
 1;
 __END__
@@ -66,9 +55,9 @@ Class for dealing with unknown RR types (RFC3597)
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2002 Michael Fuhr.
+Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2004 Chris Reinhardt.
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
 
 Portions Copyright (c) 2003  Olaf M. Kolkman, RIPE NCC.
 
