@@ -1,6 +1,6 @@
-package Net::DNS::Resolver::Cygwin; # -*- tab-width:4 -*-
+package Net::DNS::Resolver::Cygwin;
 #
-# $Id: Cygwin.pm 979 2012-01-27 08:43:38Z willem $
+# $Id: Cygwin.pm,v 1.3 2003/12/11 10:11:48 ctriv Exp $
 #
 
 use strict;
@@ -9,31 +9,31 @@ use vars qw(@ISA $VERSION);
 use Net::DNS::Resolver::Base ();
 
 @ISA	 = qw(Net::DNS::Resolver::Base);
-$VERSION = (qw$LastChangedRevision: 979 $)[1];
+$VERSION = (qw$Revision: 1.3 $)[1];
 
 sub getregkey {
 	my $key	  = $_[0] . $_[1];
 	my $value = '';
 
-	local *LM;
+	local *LM;	  
 
 	if (open(LM, "<$key")) {
 		$value = <LM>;
-		$value =~ s/\0+$// if $value;
+		$value =~ s/\0+$//;
 		close(LM);
 	}
-
+	
 	return $value;
 }
 
 sub init {
 	my ($class) = @_;
 	my $defaults = $class->defaults;
-
+	
 	local *LM;
-
+	
 	my $root = '/proc/registry/HKEY_LOCAL_MACHINE/SYSTEM/CurrentControlSet/Services/Tcpip/Parameters/';
-
+   
 	unless (-d $root) {
 		# Doesn't exist, maybe we are on 95/98/Me?
 		$root = '/proc/registry/HKEY_LOCAL_MACHINE/SYSTEM/CurrentControlSet/Services/VxD/MSTCP/';
@@ -44,22 +44,19 @@ sub init {
 	# if domain ends up blank, we're probably (?) not connected anywhere
 	# a DNS server is interesting either...
 	my $domain = getregkey($root, 'Domain') || getregkey($root, 'DhcpDomain') || '';
-
+	
 	# If nothing else, the searchlist should probably contain our own domain
 	# also see below for domain name devolution if so configured
 	# (also remove any duplicates later)
 	my $searchlist = "$domain ";
 	$searchlist	 .= getregkey($root, 'SearchList');
-
+	
 	# This is (probably) adequate on NT4
-	my $nt4nameservers = getregkey($root, 'NameServer') || getregkey($root, 'DhcpNameServer');
-	my $nameservers = "";
+	my $nameservers = getregkey($root, 'NameServer') || getregkey($root, 'DhcpNameServer');
 	#
 	# but on W2K/XP the registry layout is more advanced due to dynamically
 	# appearing connections. So we attempt to handle them, too...
 	# opt to silently fail if something isn't ok (maybe we're on NT4)
-    # If this doesn't fail override any NT4 style result we found, as it
-    # may be there but is not valid.
 	# drop any duplicates later
 	my $dnsadapters = $root . "DNSRegisteredAdapters/";
 	if (opendir(LM, $dnsadapters)) {
@@ -85,21 +82,13 @@ sub init {
 			my $regiface = $interfaces . $iface . '/';
 			if (opendir(LM, $regiface)) {
 				closedir(LM);
-
 				my $ns;
-				my $ip;
-				$ip = getregkey($regiface, "DhcpIPAddress") || getregkey($regiface, "IPAddress");
-				$ns = getregkey($regiface, "NameServer") ||
-				    getregkey($regiface, "DhcpNameServer") || ''
-                      unless !$ip || ($ip =~ /0\.0\.0\.0/);
-
+				$ns = getregkey($regiface, "NameServer");
 				$nameservers .= " $ns" if $ns;
-            }
-        }
-    }
-
-	if (!$nameservers) {
-		$nameservers = $nt4nameservers;
+				$ns = getregkey($regiface, "DhcpNameServer");
+				$nameservers .= " $ns" if $ns;
+			}
+		}
 	}
 
 	if ($domain) {
@@ -109,20 +98,20 @@ sub init {
 	my $usedevolution = getregkey($root, 'UseDomainNameDevolution');
 	if ($searchlist) {
 		# fix devolution if configured, and simultaneously make sure no dups (but keep the order)
-		my @a;
+		my $i = 0;
 		my %h;
 		foreach my $entry (split(m/[\s,]+/, $searchlist)) {
-			push(@a, $entry) unless $h{$entry};
-			$h{$entry} = 1;
+			$h{$entry} = $i++;
 			if ($usedevolution) {
 				# as long there's more than two pieces, cut
 				while ($entry =~ m#\..+\.#) {
 					$entry =~ s#^[^\.]+\.(.+)$#$1#;
-					push(@a, $entry) unless $h{$entry};
-					$h{$entry} = 1;
-					}
+					$h{$entry} = $i++;
 				}
 			}
+		}
+		my @a;
+		$a[$h{$_}] = $_ foreach (keys %h);
 		$defaults->{'searchlist'} = \@a;
 	}
 
@@ -131,10 +120,10 @@ sub init {
 		my @a;
 		my %h;
 		foreach my $ns (split(m/[\s,]+/, $nameservers)) {
-			push @a, $ns unless (!$ns || $h{$ns});
+			push @a, $ns unless $h{$ns};
 			$h{$ns} = 1;
 		}
-		$defaults->{'nameservers'} = [map { m/(.*)/ } @a];
+		$defaults->{'nameservers'} = \@a;
 	}
 
 	$class->read_env;
@@ -167,9 +156,9 @@ for all your resolving needs.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2002 Michael Fuhr.
+Copyright (c) 1997-2002 Michael Fuhr. 
 
-Portions Copyright (c) 2002-2004 Chris Reinhardt.
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
 
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
